<?php

namespace Drupal\field_updater_service;

use Drupal\Core\Config\Entity\ConfigEntityInterface;

/**
 * Provides an interface defining a field updater type entity.
 *
 * A field updater type is a wrapper around a service used to perform an update.
 */
interface FieldUpdaterTypeInterface extends ConfigEntityInterface {

  /**
   * Returns the mappings for this feed type.
   *
   * @return array
   *   The list of mappings.
   */
  public function getMappings();

  /**
   * Sets the mappings for the feed type.
   *
   * @param array $mappings
   *   A list of mappings.
   */
  public function setMappings(array $mappings);

  /**
   * Removes all mappings.
   *
   * @return $this
   *   An instance of this class.
   */
  public function removeMappings();

  /**
   * Returns the entity type id for this field updater type.
   *
   * @return string
   *   The entity type id of the configuration.
   */
  public function getUpdaterEntityTypeId(): string;

  /**
   * Returns the bundle for this field updater type.
   *
   * @return string
   *   The bundle of the configuration.
   */
  public function getUpdaterBundle(): string;

}
