<?php

namespace Drupal\field_updater_service;

use Drupal\Component\Utility\SortArray;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityListBuilder;

/**
 * Provides a listing of field updater types.
 */
class FieldUpdaterTypeListBuilder extends EntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    $row['label'] = $entity->label();
    $row['id'] = $entity->id();
    $row['operations']['data'] = $this->buildOperations($entity);
    return $row;
  }

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $row['label'] = $this->t('Label');
    $row['id'] = $this->t('Machine name');
    $row['operations'] = $this->t('Operations');
    return $row;
  }

  /**
   * {@inheritdoc}
   */
  public function getOperations(EntityInterface $entity) {
    $operations = parent::getOperations($entity);

    if ($entity->access('mapping') && $entity->hasLinkTemplate('mapping')) {
      $operations['mapping'] = [
        'title' => $this->t('Mapping'),
        'url' => $entity->toUrl('mapping'),
        // Appear after operation "edit".
        'weight' => 11,
      ];
    }

    uasort($operations, [SortArray::class, 'sortByWeightElement']);

    return $operations;
  }

}
